
RELEASE_VERSION='0.0.383715870'
BUILD_DATE='Wed Oct  6 16:17:00 UTC 2021'
BUILD_MACHINE_INFO='Linux runner-mvj-ljo-project-28359933-concurrent-0rdzv5 5.4.129-62.227.amzn2.x86_64 #1 SMP Wed Jul 7 00:08:43 UTC 2021 x86_64 GNU/Linux'
GITLAB_CI_JOB_ID='1655524253'
GIT_COMMIT_SHA='2e397c9ad15360a2ea1970d543977480aaefeb00'
GIT_BRANCH='main'
